<?php
/**
 * Vega WP functions and definitions
 *
 * @package vega
 */
?>
<?php


### THEME DEFAULTS ###

require get_template_directory() . '/customize/theme-defaults.php';
define('SHOW_UPGRADE', true);


### SETUP ###

function vega_wp_setup() {

    global $vega_wp_defaults;
    
    #make theme available for translation. Translations can be filed in the /languages/ directory
    load_theme_textdomain( 'vega', get_template_directory() . '/languages' ); 

    #add default posts and comments RSS feed links to head
    add_theme_support( 'automatic-feed-links' );

    #let WordPress manage the document title
    add_theme_support( 'title-tag' );

    #support for post thumbnails on posts and pages
    add_theme_support( 'post-thumbnails' );
    set_post_thumbnail_size( 300, 250, true );
    add_image_size( 'post-thumbnail-recent', 350, 220, true );

    #navigation menus
    register_nav_menus( array(
        'header'    =>  __( 'Header Menu', 'vega' ),
        'footer'    =>  __( 'Footer Menu', 'vega' ),
    ) );
    
    #custom header support
    $args = array(
        'flex-width'    => true,
        'width'         => 1920,
        'flex-height'    => true,
        'height'        => 250,
        'default-image' => $vega_wp_defaults['vega_wp_custom_header'],
    );
    add_theme_support( 'custom-header', $args );
    
    #page excerpts
    add_post_type_support('page', 'excerpt');
    
    //$vega_wp_admin_bar = vega_wp_get_option('vega_wp_admin_bar'); 
    //if($vega_wp_admin_bar == 'N' && !is_admin()) { show_admin_bar( false ); }
    
}
add_action( 'after_setup_theme', 'vega_wp_setup' );


if ( ! isset( $content_width ) ) {
    $content_width = 1200;
}


### FILTERS ###

function vega_wp_filter_media_comment_status( $open, $post_id ) {
	$post = get_post( $post_id );
	if( $post->post_type == 'attachment' ) {
		return false;
	}
	return $open;
}
add_filter( 'comments_open', 'vega_wp_filter_media_comment_status', 10 , 2 );


function vega_wp_move_comment_field_to_bottom( $fields ) {
    $comment_field = $fields['comment'];
    unset( $fields['comment'] );
    $fields['comment'] = $comment_field;
    return $fields;
}
add_filter( 'comment_form_fields', 'vega_wp_move_comment_field_to_bottom' );

function vega_wp_excerpt_length( $length ) {
	return 65;
}
add_filter( 'excerpt_length', 'vega_wp_excerpt_length', 999 );


### STYLES AND SCRIPTS ###

function vega_wp_scripts() {
    
    /** CSS **/
    
    #bootstrap, fontawesome, bootstrapsocial
    wp_register_style('bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.min.css' );
    wp_register_style('font-awesome', get_template_directory_uri().'/assets/css/font-awesome.min.css' );
    wp_register_style('bootstrap-social', get_template_directory_uri().'/assets/css/bootstrap-social.css' );
    
    #animate.css
    wp_register_style('animate-css', get_template_directory_uri().'/assets/css/animate.css' );
    wp_enqueue_style('animate-css');
    
    #fonts
    wp_register_style('vega-wp-googlefont1', '//fonts.googleapis.com/css?family=Raleway:400,700,400italic,700italic,300,300italic,200italic,500,100,100italic,200,500italic,600,600italic,800,800italic,900,900italic');
    wp_register_style('vega-wp-googlefont2', '//fonts.googleapis.com/css?family=Lato:400,100,100italic,300,300italic,400italic,700,700italic,900,900italic');
    wp_enqueue_style('vega-wp-googlefont1');
    wp_enqueue_style('vega-wp-googlefont2');

    #default stylesheet
    $deps = array('bootstrap', 'font-awesome', 'bootstrap-social');
    wp_register_style('vega-wp-style', get_stylesheet_uri(), $deps );
    wp_enqueue_style('vega-wp-style' );
        
    #color scheme
    $vega_wp_color_stylesheet = vega_wp_get_option('vega_wp_color_stylesheet');
    wp_register_style('vega-wp-color', get_stylesheet_uri() . '/color-schemes/' . strtolower($vega_wp_color_stylesheet) . '.css');
    wp_enqueue_style('vega-wp-color');
    
    /** Javascript **/
    
    #bootstrap
    wp_enqueue_script('bootstrap', get_template_directory_uri().'/assets/js/bootstrap.min.js', array('jquery'), '', true );
    wp_enqueue_script('jquery-smartmenus', get_template_directory_uri() . '/assets/js/jquery.smartmenus.min.js', array('jquery'), '', true );
    wp_enqueue_script('jquery-smartmenus-bootstrap', get_template_directory_uri() . '/assets/js/jquery.smartmenus.bootstrap.min.js', array('jquery'), '', true );
        
    #animation
    $vega_wp_animations = vega_wp_get_option('vega_wp_animations');
    if($vega_wp_animations == 'Y') {
        wp_enqueue_script('wow', get_template_directory_uri() . '/assets/js/wow.min.js', array('jquery'), '', true );
        wp_enqueue_script('vega-wp-themejs-anim', get_template_directory_uri() . '/assets/js/vega-wp-anim.js', array('jquery'), '', true );
    }
    
    #theme javascript
    wp_enqueue_script('vega-wp-themejs', get_template_directory_uri() . '/assets/js/vega-wp.js', array('jquery'), '', true );
    
    #comments
    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
        wp_enqueue_script( 'comment-reply' );
    }
    
}
add_action( 'wp_enqueue_scripts', 'vega_wp_scripts' );


### CUSTOM CSS ###

function vega_wp_custom_css() {
    $vega_wp_custom_css = vega_wp_get_option('vega_wp_custom_css'); 
	echo '<!-- Custom CSS -->';
    $output="<style>" . stripslashes($vega_wp_custom_css) . "</style>";
    echo $output;
    echo '<!-- /Custom CSS -->';
}
add_action('wp_head','vega_wp_custom_css');


### CUSTOMIZER STYLES ("Upgrade to Pro") ###
add_action( 'customize_controls_enqueue_scripts', 'vega_wp_custom_customize_enqueue' );
function vega_wp_custom_customize_enqueue() {
    wp_enqueue_style( 'customizer-css', get_template_directory_uri() . '/customize/style.css' );
}


### WIDGETS ###

function vega_wp_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'vega' ),
		'id'            => 'sidebar',
		'description'   => __( 'Add widgets here to appear in your sidebar.', 'vega' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
    register_sidebar( array(
		'name'          => __( 'Footer Col 1', 'vega' ),
		'id'            => 'footer_1',
		'description'   => __( 'Add widgets here to appear in the first column of the footer.', 'vega' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
    register_sidebar( array(
		'name'          => __( 'Footer Col 2', 'vega' ),
		'id'            => 'footer_2',
		'description'   => __( 'Add widgets here to appear in the second column of the footer.', 'vega' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
    register_sidebar( array(
		'name'          => __( 'Footer Col 3', 'vega' ),
		'id'            => 'footer_3',
		'description'   => __( 'Add widgets here to appear in the third column of the footer.', 'vega' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
    register_sidebar( array(
		'name'          => __( 'Footer Col 4', 'vega' ),
		'id'            => 'footer_4',
		'description'   => __( 'Add widgets here to appear in the fourth column of the footer.', 'vega' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'vega_wp_widgets_init' );


### INCLUDES ###

#bootstrap nav walker
require get_template_directory() . '/includes/wp_bootstrap_navwalker.php';
#customizer
require get_template_directory() . '/customize/customizer.php';


### FUNCTIONS ###

#vega_wp_copyright
function vega_wp_copyright() {
    $vega_wp_footer_copyright_message = vega_wp_get_option('vega_wp_footer_copyright_message'); 
    ?>
    <div class="copyright"><?php echo $vega_wp_footer_copyright_message ?></div>
    <?php 
}

#vega_wp_rand_page
function vega_wp_rand_page() {
    $pages = get_pages();
    if(!empty($pages)) {    
        shuffle($pages);
        return $pages[0]->ID; 
    } else {
        return false;
    }
} 

#vega_wp_title
function vega_wp_title() {
    if( is_home() && get_option('page_for_posts') ) :
        echo apply_filters('the_title',get_page( get_option('page_for_posts') )->post_title);
        //bloginfo('name'); 
    elseif ( is_page() ) :
        $title = get_the_title(); if($title != '') the_title(); else echo __("Page ID: ", 'vega') . get_the_ID();
    elseif (is_single() ):
        $title = get_the_title(); if($title != '') the_title(); else echo __("Post ID: ", 'vega') . get_the_ID();
    elseif ( is_category() ) :
        single_cat_title();
    elseif ( is_tag() ) :
        _e("Tag: ", 'vega'); single_tag_title();
    elseif ( is_author() ) :
        printf( esc_html__( 'Author: %s', 'vega' ), '<span>' . get_the_author() . '</span>' );
    elseif ( is_day() ) :
        printf( esc_html__( 'Day: %s', 'vega' ), '<span>' . get_the_date() . '</span>' );
    elseif ( is_month() ) :
        printf( esc_html__( 'Month: %s', 'vega' ), '<span>' . get_the_date( _x( 'F Y', 'monthly archives date format', 'vega' ) ) . '</span>' );
    elseif ( is_year() ) :
        printf( esc_html__( 'Year: %s', 'vega' ), '<span>' . get_the_date( _x( 'Y', 'yearly archives date format', 'vega' ) ) . '</span>' );
    elseif ( is_404() ) :
        _e('Not Found!', 'vega');
    elseif ( is_search() ) :
        _e('Search Results: ', 'vega'); echo get_search_query();
    else :
        _e( 'Archives', 'vega' );
    endif;
} 

#vega_wp_get_col_class
function vega_wp_get_col_class($n){
    switch($n){
        case 1: return 'col-md-12'; break;
        case 2: return 'col-md-6'; break;
        case 3: return 'col-md-4'; break;
        case 4: return 'col-md-3'; break;
    }
}


#vega_wp_get_option
function vega_wp_get_option($key){
    global $vega_wp_defaults;
    if (array_key_exists($key, $vega_wp_defaults)) 
        $value = get_theme_mod($key, $vega_wp_defaults[$key]); 
    else
        $value = get_theme_mod($key);
    return $value;
}

### EXAMPLE CONTENT ###

#vega_wp_random_thumbnail
function vega_wp_random_thumbnail($size='default'){
    global $vega_wp_defaults;
    if($size == 'post-thumbnail-recent')
        $images = $vega_wp_defaults['vega_wp_recent_post_image'];
    else 
        $images = $vega_wp_defaults['vega_wp_featured_image'];
    $rand_key = array_rand($images, 1);
    echo esc_url($images[$rand_key]);
}

#vega_wp_sequential_thumbnail
function vega_wp_sequential_thumbnail($size, $n){
    global $vega_wp_defaults;
    if($size == 'post-thumbnail-recent')
        $images = $vega_wp_defaults['vega_wp_recent_post_image'];
    else 
        $images = $vega_wp_defaults['vega_wp_featured_image'];
    echo esc_url($images[$n]); 
}

#vega_wp_example_nav_header
function vega_wp_example_nav_header(){
    $args = array('parent'=>0);
    $pages = get_pages($args);
    echo '<div class="navbar-collapse collapse"><ul class="nav navbar-nav navbar-right">';
    foreach($pages as $page) 
        echo '<li><a href="'.get_permalink($page->ID).'">'.$page->post_title.'</a></li>';
    echo '</ul>';
    echo '</div>';
}

#vega_wp_example_banner
function vega_wp_example_banner(){
    $image = esc_url( get_template_directory_uri() ) . '/sample/images/header.png';
    echo '<div class="jumbotron image-banner banner-custom-header" style="background:url(\''.$image.'\') no-repeat 0 0 #ffffff;background-size:cover;background-position:center center"><div class="container"><h1 class="block-title">Your Awesome Tagline</h1></div></div>';
}

#vega_wp_example_fullscreen_banner
function vega_wp_example_fullscreen_banner(){
    $image = esc_url( get_template_directory_uri() ) . '/sample/images/fullscreen.jpg';
    echo '<div class="jumbotron image-banner frontpage-banner full-screen example-fullscreen-banner" style="background:url(\''.$image. '\') no-repeat 0 0 #ffffff;background-size:cover;background-position:center center"><div class="container"><div class="inner"><h1 class="block-title wow zoomIn">Clean Responsive Wordpress Theme</h1><p class="text-center hidden-xs wow zoomIn">Vega is an easy-to-use, responsive theme. It comes with<br />awesome animation effects, and super clean code.</p><p><br /><a class="btn btn-primary-custom" href="#" role="button">DOWNLOAD NOW</a></p></div><div class="helper"></div></div></div>';
}

#vega_wp_example_nav_footer
function vega_wp_example_nav_footer(){
    $args = array('parent'=>0);
    $pages = get_pages($args);
    echo '<ul id="menu-footer" class="nav-foot">';
    foreach($pages as $page) 
        echo '<li><a href="'.get_permalink($page->ID).'">'.$page->post_title.'</a></li>';
    echo '</ul>';
}

#vega_wp_example_frontpage_content
function vega_wp_example_frontpage_content(){
    echo '<h2 class="block-title wow zoomIn">Welcome to Vega</h2>
<div class="wow fadeInUp"><p>Etiam sed eleifend tellus. Curabitur volutpat feugiat congue. Suspendisse potenti. Aenean rhoncus nunc id semper mollis. Aenean pulvinar, leo non elementum sollicitudin, enim neque viverra neque, quis consequat orci tellus vitae libero. Quisque et metus ultricies, malesuada turpis nec, malesuada enim.</p><p style="margin-top: 20px;"><a class="btn btn-inverse" href="#">LEARN MORE</a></p></div>';
}

#vega_wp_example_sidebar_footer
function vega_wp_example_sidebar_footer(){
    echo '<div class="footer-widgets bg-grey-light-3"><div class="container"><div class="row"><div class="col-md-3 footer-widget footer-widget-col-1"><div class="widget widget_text"><h3 class="widget-title">About Vega Lite</h3><div class="textwidget">These are example widgets. Turn off demo data to set up your own.<br /><br /><a href="#" class="btn btn-social-icon btn-twitter"><i class="fa fa-twitter"></i></a>&nbsp;<a href="#" class="btn btn-social-icon btn-facebook"><i class="fa fa-facebook"></i></a>&nbsp;<a href="#" class="btn btn-social-icon btn-flickr"><i class="fa fa-flickr"></i></a>&nbsp;<a href="#" class="btn btn-social-icon btn-google"><i class="fa fa-google"></i></a></div></div></div>';
    echo '<div class="col-md-3 footer-widget footer-widget-col-2">';
    the_widget('WP_Widget_Recent_Posts', 'title=Recent Posts', 'before_title=<h3 class="widget-title">&after_title=</h3>&before_widget=<div class="widget">&after_widget=</div>');
    echo '</div>';
    echo '<div class="col-md-3 footer-widget footer-widget-col-3">';
    the_widget('WP_Widget_Categories', 'title=Categories', 'before_title=<h3 class="widget-title">&after_title=</h3>&before_widget=<div class="widget">&after_widget=</div>');
    echo '</div>';
    echo '<div class="col-md-3 footer-widget footer-widget-col-3">';
    the_widget( 'WP_Widget_Meta', 'title=Meta', 'before_title=<h3 class="widget-title">&after_title=</h3>&before_widget=<div class="widget">&after_widget=</div>');
    echo '</div></div></div></div>';
}

#vega_wp_example_sidebar
function vega_wp_example_sidebar(){
    echo '<div class="sidebar-widgets" >';
    the_widget('WP_Widget_Pages', 'title=Pages', 'before_title=<h3 class="widget-title">&after_title=</h3>&before_widget=<div class="widget">&after_widget=</div>');
    the_widget('WP_Widget_Recent_Posts', 'title=Recent Posts', 'before_title=<h3 class="widget-title">&after_title=</h3>&before_widget=<div class="widget">&after_widget=</div>');
    the_widget('WP_Widget_Recent_Comments', 'title=Recent Comments', 'before_title=<h3 class="widget-title">&after_title=</h3>&before_widget=<div class="widget">&after_widget=</div>');
    the_widget( 'WP_Widget_Archives', 'title=Archives', 'before_title=<h3 class="widget-title">&after_title=</h3>&before_widget=<div class="widget">&after_widget=</div>');
    the_widget( 'WP_Widget_Categories', 'title=Categories', 'before_title=<h3 class="widget-title">&after_title=</h3>&before_widget=<div class="widget">&after_widget=</div>');
    echo '</div>';
}


?>